@@ -24,7 +24,7 @@ def compare_yidun_whisper_results(result_file: str, target_file: str, columns=["
 def parse_yidun_json(yidun_json: str, standard_json=True):
     if not standard_json:
         yidun_json = yidun_json.replace("'", '"')
-    x = yidun_json.replace("\\x", "")
+    x = yidun_json.replace("\0", "")
     data = json.loads(x)
     data = data["result"]
     _type = id2label[data['labels'][0]['label']] if data['labels'] else '健康'
