@@ -116,7 +116,7 @@ class NetEaseStatistics(Statistics):
         self.df_review2reject.columns = ["example", "label", "type", "predict_label", "predict_type"]
 
     def parse_result_json(self, x: str):
-        x = x.replace("'", '"').replace("\\x0", "")
+        # x = x.replace("\\x", "")
         a = json.loads(x)
         data = a["result"]
         _type = self.id2label[data['labels'][0]['label']] if data['labels'] else '健康'
