@@ -1,5 +1,5 @@
 from whisper_evaluate import Statistics
-import numpy as np
+from whisper_evaluate.utils import _get_result_type
 import pandas as pd
 from pandarallel import pandarallel
 from whisper_evaluate.config import en_zh
@@ -92,7 +92,7 @@ class WhisperStatistics(Statistics):
         # self.__parse_result_json(standard_df)
 
     def _parse_result_json(self, x: str):
-        x = x.replace("'", '"')
+        # x = x.replace("'", '"')
         a = json.loads(x)
         results = a['results'][0]
         _match_words = results['matched_words']
@@ -108,40 +108,6 @@ class WhisperStatistics(Statistics):
                 " ".join([x["word"] for x in _new_words]),
                 " ".join([x["word"] for x in _review_words]))
 
-    # def __parse_result_json(self, standard_df: pd.DataFrame):
-    #
-    #     result = []
-    #
-    #     _iter = standard_df.result_json
-    #     for line in _iter:
-    #         a = eval(line)
-    #         results = a['results'][0]
-    #         _match_words = results['matched_words']
-    #         _new_words = results['new_words']
-    #         _review_words = results['review_words']
-    #         predict_type = self._get_result_type(_match_words + _new_words)
-    #         predict_label = "Pass" if predict_type == "其他" else "Reject"
-    #         predict_type_trie = "政治" if self._get_result_type(_review_words) == "政治" else predict_type
-    #         predict_label_trie = "Pass" if predict_type_trie == "其他" else "Reject"
-    #         result.append([predict_label, predict_type, predict_label_trie, predict_type_trie,
-    #                        " ".join([x["word"] for x in _match_words]), " ".join([x["word"] for x in _new_words]),
-    #                        " ".join([x["word"] for x in _review_words])])
-    #
-    #     result = np.array(result)
-    #     if 'res_json' in standard_df.columns:
-    #         standard_df.drop(columns=['res_json'])
-    #     standard_df["predict_label"] = pd.Series(result[:, 0])
-    #     standard_df["predict_type"] = pd.Series(result[:, 1])
-    #     standard_df["predict_label_trie"] = pd.Series(result[:, 2])
-    #     standard_df["predict_type_trie"] = pd.Series(result[:, 3])
-    #     standard_df["match_words"] = pd.Series(result[:, 4])
-    #     standard_df["new_words"] = pd.Series(result[:, 5])
-    #     standard_df["review_words"] = pd.Series(result[:, 6])
-    #     self.df = standard_df
-    #     self.df_no_trie = standard_df[["example", "label", "type", "predict_label", "predict_type"]]
-    #     self.df_trie = standard_df[["example", "label", "type", "predict_label_trie", "predict_type_trie"]]
-    #     self.df_trie.columns = ["example", "label", "type", "predict_label", "predict_type"]
-
     def __count_f1(self):
         for category in self.indicator["no_trie"]["precision"]:
             self.indicator["no_trie"]["f1"][category] = self.f1(self.indicator["no_trie"]["precision"][category][0],
@@ -159,31 +125,4 @@ class WhisperStatistics(Statistics):
         self.__count_f1()
 
     def _get_result_type(self, words: list):
-        tag_set = set()
-        if not words:
-            return en_zh["Normal"]
-        for element in words:
-            tag_set.add(element["type"])
-        if "Politics" in tag_set:
-            return en_zh["Politics"]
-        if "Heresy" in tag_set:
-            return en_zh["Heresy"]
-        if "Terrorism" in tag_set:
-            return en_zh["Terrorism"]
-        if "Crime" in tag_set:
-            return en_zh["Crime"]
-        if "Porn" in tag_set:
-            return en_zh["Porn"]
-        if "Gamble" in tag_set:
-            return en_zh["Gamble"]
-        if "Contraband" in tag_set:
-            return en_zh["Contraband"]
-        if "SensitiveEvent" in tag_set:
-            return en_zh["SensitiveEvent"]
-        if "Abuse" in tag_set:
-            return en_zh["Abuse"]
-        if "IllegalWebsite" in tag_set:
-            return en_zh["IllegalWebsite"]
-        if "Adv" in tag_set:
-            return en_zh["Adv"]
-        return en_zh["Normal"]
+        return _get_result_type(words)
